"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConnectToken = exports.getConnectTokenStore = void 0;
const fs = __importStar(require("fs-extra"));
const prompts_1 = require("@inquirer/prompts");
const core_1 = require("@oclif/core");
/**
 * Gets the Connect Auth token that should be used for the API requests to the Connect API.
 * First attempts to read from the environment variable CONNECT_AUTH_TOKEN. If it is not present
 * it will prompt the user for the token instead. If `canSave` is true, it will also prompt the user
 * if they want to save the token to the .env file.
 *
 * @param canSave Whether this is being called from a state where a token
 * received by prompt can be saved to the .env file. For example, when running during
 * the init command the repository does not yet exist and so there is nowhere to save the
 * token when this function runs.
 * @returns The connect auth token that should be used for the API requests.
 */
function getConnectTokenStore() {
    let connectToken;
    return async function getConnectToken(canSave = true) {
        if (!connectToken) {
            if (!process.env.CONNECT_AUTH_TOKEN) {
                core_1.ux.log();
                connectToken = await core_1.ux.prompt("Enter your Connect Auth token 🔐", {
                    type: "mask",
                });
                if (canSave) {
                    const saveToken = await (0, prompts_1.confirm)({
                        message: "💾 Do you want to save this token in your .env for future use?",
                    });
                    if (saveToken) {
                        fs.appendFileSync(".env", `CONNECT_AUTH_TOKEN=${connectToken}\n`);
                    }
                    core_1.ux.log();
                }
            }
            else {
                connectToken = process.env.CONNECT_AUTH_TOKEN;
            }
        }
        return connectToken;
    };
}
exports.getConnectTokenStore = getConnectTokenStore;
exports.getConnectToken = getConnectTokenStore();
