"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanupExternalDataPath = exports.cleanupFixturePath = exports.cleanupTemplatePath = exports.getCustomerPath = void 0;
/* eslint-disable @typescript-eslint/prefer-nullish-coalescing */
const path_1 = require("path");
/**
 * @returns The provided path prepended with the root directory.
 */
function getCustomerPath(path) {
    return (0, path_1.join)(process.cwd(), process.env.REPOSITORY_ROOT_DIRECTORY || "", path);
}
exports.getCustomerPath = getCustomerPath;
/**
 * Cleans up the template path, removing the root directory and the 'src/templates' prefix.
 *
 * This is needed to support the use of absolute paths in the templates, since those will
 * be added later on when reading the files.
 */
function cleanupTemplatePath(path) {
    return cleanupAbsolutePath(path).replace("/src/templates/", "");
}
exports.cleanupTemplatePath = cleanupTemplatePath;
/**
 * Cleans up the fixture path, removing the root directory and the 'src/fixtures' prefix.
 *
 * This is needed to support the use of absolute paths in the templates, since those will
 * be added later on when reading the files.
 */
function cleanupFixturePath(path) {
    return cleanupAbsolutePath(path).replace("/src/fixtures/", "");
}
exports.cleanupFixturePath = cleanupFixturePath;
/**
 * Cleans up the external data path, removing the root directory and the 'src/external-data' prefix.
 *
 * This is needed to support the use of absolute paths in the templates, since those will
 * be added later on when reading the files.
 */
function cleanupExternalDataPath(path) {
    return cleanupAbsolutePath(path).replace("/src/external-data/", "");
}
exports.cleanupExternalDataPath = cleanupExternalDataPath;
function cleanupAbsolutePath(path) {
    if (!path) {
        return "";
    }
    return path.replace(process.cwd(), "");
}
