"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFileLoader = exports.getJSONataTemplate = exports.getExternalDataFixture = exports.getCatalogFixture = void 0;
const path_1 = __importDefault(require("path"));
const errors_1 = require("@oclif/core/lib/errors");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_2 = require("../customer/path");
exports.getCatalogFixture = createFileLoader({
    prefix: "src/fixtures",
    fileLoader: fs_extra_1.default.readJSONSync,
    suggestions: ["Ensure the file is a valid JSON file"],
});
exports.getExternalDataFixture = createFileLoader({
    prefix: "src/fixtures/external_data",
    fileLoader: fs_extra_1.default.readJSONSync,
    suggestions: ["Ensure the file is a valid JSON file"],
});
exports.getJSONataTemplate = createFileLoader({
    prefix: "src/templates",
    fileLoader: fs_extra_1.default.readFileSync,
});
function createFileLoader({ prefix, fileLoader, suggestions = [], }) {
    return function (name, ...args) {
        const filePath = (0, path_2.getCustomerPath)(path_1.default.join(prefix, name));
        try {
            return fileLoader(filePath, ...args);
        }
        catch (error) {
            throw new errors_1.CLIError(`Error while loading ${filePath}: ${error.message}`, {
                suggestions: [
                    "Ensure the file exists and is named correctly",
                    ...suggestions,
                ],
            });
        }
    };
}
exports.createFileLoader = createFileLoader;
