"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeTemplates = void 0;
const axios_1 = require("axios");
const errors_1 = require("@oclif/core/lib/errors");
const ux_action_1 = require("../helpers/ux-action");
const http_client_1 = require("./http-client");
async function executeTemplates({ template, helpers, targetData, externalData, connectionId, }) {
    const client = await (0, http_client_1.getHttpClient)();
    try {
        return await (0, ux_action_1.uxAction)("📟 Executing your template", async () => {
            return (await client.patch("templates/standalone/execute", {
                raw_template: template,
                helpers,
                target_data: targetData,
                external_data: externalData,
                connection_id: connectionId,
            })).data;
        })();
    }
    catch (error) {
        if ((0, axios_1.isAxiosError)(error) && error.response) {
            throw new errors_1.CLIError(`Something went wrong while executing your template: ${JSON.stringify(error.response.data)}`);
        }
        throw error;
    }
}
exports.executeTemplates = executeTemplates;
