"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterConnectionsByTemplate = void 0;
const path_1 = __importDefault(require("path"));
const config_1 = require("../customer/config");
async function filterConnectionsByTemplate(templatePath, connections) {
    const config = await (0, config_1.getRepositoryConfigFile)();
    const fullPath = path_1.default.join("src/templates", templatePath);
    // Find the config mappings that have the template.
    const connectionIds = config.environments.reduce((connectionIds, env) => {
        env.templates.forEach((templateConfig) => {
            const templatePaths = Object.values(templateConfig.paths);
            if (templatePaths.includes(fullPath)) {
                templateConfig.connection_ids.forEach((id) => connectionIds.add(id));
            }
        });
        return connectionIds;
    }, new Set());
    const filteredConnections = connections.filter((c) => connectionIds.has(c.id));
    return filteredConnections.map((c) => {
        return {
            name: c.name,
            value: c,
        };
    });
}
exports.filterConnectionsByTemplate = filterConnectionsByTemplate;
