"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCandidateFixtures = void 0;
const path_1 = __importDefault(require("path"));
const errors_1 = require("@oclif/core/lib/errors");
const find_deep_files_1 = require("../helpers/find-deep-files");
const get_template_files_1 = require("./get-template-files");
function getCandidateFixtures(templatePath) {
    const templateType = extractTemplateType(templatePath);
    if (!templateType) {
        throw new errors_1.CLIError(`Couldn't find the template type by looking at its path: ${templatePath}`, {
            suggestions: [
                "Check that the template file path is correct",
                "Check that your templates are in the correctly named directory for their type (e.g. 'item.jsonata' in the 'templates/item' directory",
                "Check that you are using a valid template type: " +
                    get_template_files_1.templateTypes.join(", "),
            ],
        });
    }
    const fixtureType = templateType === "grouping" ? "variation" : templateType;
    let fixtureFullPaths;
    try {
        fixtureFullPaths = (0, find_deep_files_1.findDeepFiles)(`src/fixtures/${fixtureType}`);
    }
    catch (error) {
        if (error instanceof Error && error.message.includes("ENOENT")) {
            throw new errors_1.CLIError(`Directory for ${fixtureType} fixtures (at src/fixtures/${fixtureType}) does not exist.`, {
                suggestions: [
                    `If the ${fixtureType} directory has been deleted, recreate it and add fixtures to it.`,
                    `Ensure the ${fixtureType} directory is named correctly`,
                ],
            });
        }
        throw error;
    }
    return fixtureFullPaths
        .filter((fixturePath) => path_1.default.extname(fixturePath) === ".json")
        .map((fixturePath) => {
        const fixtureRelativePath = path_1.default.relative("src/fixtures", fixturePath);
        return {
            name: fixtureRelativePath,
            value: fixtureRelativePath,
        };
    });
}
exports.getCandidateFixtures = getCandidateFixtures;
/**
 * Checks for any nested folder that matches a known template type.
 */
function extractTemplateType(templatePath) {
    for (const type of get_template_files_1.templateTypes) {
        if (templatePath.includes(`${type}/`)) {
            return type;
        }
    }
}
