"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplateFiles = exports.templateTypes = void 0;
const path_1 = __importDefault(require("path"));
const find_deep_files_1 = require("../helpers/find-deep-files");
exports.templateTypes = [
    "item",
    "variation",
    "item_group",
    "grouping",
    "mapping",
];
/**
 * Get a prompt-ready list of template files in the user repository
 */
async function getTemplateFiles() {
    let files = [];
    for (const type of exports.templateTypes) {
        const typePath = path_1.default.join("src/templates", type);
        files = files.concat(getTemplatePaths(typePath));
    }
    const filteredFiles = files.filter((file) => file.endsWith(".jsonata") && !file.includes("helpers"));
    return filteredFiles.map((file) => ({
        name: file.replace("src/templates/", ""),
        value: file.replace("src/templates/", ""),
    }));
}
exports.getTemplateFiles = getTemplateFiles;
/**
 * @param typePath The full type path. E.g.
 * - src/templates/item
 * - src/templates/variation
 * @returns A list of template paths for the given type. E.g.
 * - src/templates/item/1.jsonata
 * - src/templates/item/2.jsonata
 */
function getTemplatePaths(typePath) {
    try {
        return (0, find_deep_files_1.findDeepFiles)(typePath);
    }
    catch (error) {
        if (error instanceof Error && error.message.includes("ENOENT")) {
            return [];
        }
        throw error;
    }
}
