"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderRepeatInput = void 0;
const core_1 = require("@oclif/core");
const kleur_1 = __importDefault(require("kleur"));
const generate_command_input_1 = require("../helpers/generate-command-input");
/**
 * Prints the text of the command you would need to put into the terminal in order to replicate
 * the previously executed command, but with awareness of inputs provided during the execution
 * of the command itself (through a select prompt for example).
 *
 * This extra awareness is provided through the `inputFlags` parameter which you can use
 * to specify the specific values of each flag in order to replicate the current command.
 *
 * @param commandName Name of the command that should be printed.
 * @param inputFlags A map of flag names to the values that should be printed in the command.
 */
function renderRepeatInput(command, inputFlags) {
    core_1.ux.log(kleur_1.default.bold(`\nInput to replicate this command ⬇️\n`) +
        kleur_1.default.magenta((0, generate_command_input_1.generateCommandInput)({ commandName: command.id ?? "", inputFlags })));
}
exports.renderRepeatInput = renderRepeatInput;
